Crate amareleo_node_bft

Crate amareleo_node_bft 

Re-exports

pub use amareleo_node_bft_ledger_service as ledger_service;
pub use amareleo_node_bft_storage_service as storage_service;

Modules

helpers

Macros

spawn_blocking
A helper macro to spawn a blocking task.

Structs

BFT
Primary
Sync
Worker

Constants

DEVELOPMENT_MODE_NUM_GENESIS_COMMITTEE_MEMBERS
The development mode number of genesis committee members.
DEVELOPMENT_MODE_RNG_SEED
The development mode RNG seed.
MAX_BATCH_DELAY_IN_MS
The maximum number of milliseconds to wait before proposing a batch.
MAX_LEADER_CERTIFICATE_DELAY_IN_SECS
The maximum number of seconds allowed for the leader to send their certificate.
MAX_TIMESTAMP_DELTA_IN_SECS
The maximum number of seconds before the timestamp is considered expired.
MAX_WORKERS
The maximum number of workers that can be spawned.
MIN_BATCH_DELAY_IN_SECS
The minimum number of seconds to wait before proposing a batch.

Type Aliases

ProposedBatch
A helper type for an optional proposed batch.