pub struct Proposal<N: Network> { /* private fields */ }Implementations
Sourceimpl<N: Network> Proposal<N>
impl<N: Network> Proposal<N>
Sourcepub fn new(
committee: Committee<N>,
batch_header: BatchHeader<N>,
transmissions: IndexMap<TransmissionID<N>, Transmission<N>>,
) -> Result<Self>
pub fn new( committee: Committee<N>, batch_header: BatchHeader<N>, transmissions: IndexMap<TransmissionID<N>, Transmission<N>>, ) -> Result<Self>
Initializes a new instance of the proposal.
Sourcepub const fn batch_header(&self) -> &BatchHeader<N>
pub const fn batch_header(&self) -> &BatchHeader<N>
Returns the proposed batch header.
Sourcepub const fn transmissions(
&self,
) -> &IndexMap<TransmissionID<N>, Transmission<N>>
pub const fn transmissions( &self, ) -> &IndexMap<TransmissionID<N>, Transmission<N>>
Returns the transmissions.
Sourcepub fn into_transmissions(self) -> IndexMap<TransmissionID<N>, Transmission<N>>
pub fn into_transmissions(self) -> IndexMap<TransmissionID<N>, Transmission<N>>
Returns the transmissions.
Sourcepub fn nonsigners(&self, committee: &Committee<N>) -> HashSet<Address<N>>
pub fn nonsigners(&self, committee: &Committee<N>) -> HashSet<Address<N>>
Returns the nonsigners.
Sourcepub fn is_quorum_threshold_reached(&self, committee: &Committee<N>) -> bool
pub fn is_quorum_threshold_reached(&self, committee: &Committee<N>) -> bool
Returns true if the quorum threshold has been reached for the proposed batch.
Sourcepub fn contains_transmission(
&self,
transmission_id: impl Into<TransmissionID<N>>,
) -> bool
pub fn contains_transmission( &self, transmission_id: impl Into<TransmissionID<N>>, ) -> bool
Returns true if the proposal contains the given transmission ID.
Sourcepub fn get_transmission(
&self,
transmission_id: impl Into<TransmissionID<N>>,
) -> Option<&Transmission<N>>
pub fn get_transmission( &self, transmission_id: impl Into<TransmissionID<N>>, ) -> Option<&Transmission<N>>
Returns the transmission for the given transmission ID.
Sourcepub fn add_signature(
&mut self,
signer: Address<N>,
signature: Signature<N>,
committee: &Committee<N>,
) -> Result<()>
pub fn add_signature( &mut self, signer: Address<N>, signature: Signature<N>, committee: &Committee<N>, ) -> Result<()>
Adds a signature to the proposal, if the signature is valid.
Sourcepub fn to_certificate(
&self,
committee: &Committee<N>,
) -> Result<(BatchCertificate<N>, IndexMap<TransmissionID<N>, Transmission<N>>)>
pub fn to_certificate( &self, committee: &Committee<N>, ) -> Result<(BatchCertificate<N>, IndexMap<TransmissionID<N>, Transmission<N>>)>
Returns the batch certificate and transmissions.