pub struct Sync<N: Network> { /* private fields */ }Implementations
Sourceimpl<N: Network> Sync<N>
impl<N: Network> Sync<N>
Sourceimpl<N: Network> Sync<N>
impl<N: Network> Sync<N>
Sourcepub fn num_blocks_behind(&self) -> u32
pub fn num_blocks_behind(&self) -> u32
Returns the number of blocks the node is behind the greatest peer height.
Sourcepub const fn is_gateway_mode(&self) -> bool
pub const fn is_gateway_mode(&self) -> bool
Returns true if the node is in gateway mode.
Sourcepub fn get_block_locators(&self) -> Result<BlockLocators<N>>
pub fn get_block_locators(&self) -> Result<BlockLocators<N>>
Returns the current block locators of the node.